==> nautilus-3.5.90.tar.xz: nautilus-3.5.90/libnautilus-private/nautilus-icon-names.h <==
#ifndef NAUTILUS_ICON_NAMES_H
#define NAUTILUS_ICON_NAMES_H

/* Icons for places */
#define NAUTILUS_ICON_FILESYSTEM	"drive-harddisk-symbolic"
#define NAUTILUS_ICON_FOLDER		"folder-symbolic"
#define NAUTILUS_ICON_FOLDER_REMOTE	"folder-remote-symbolic"
#define NAUTILUS_ICON_HOME		"user-home-symbolic"
#define NAUTILUS_ICON_NETWORK		"network-workgroup-symbolic"
#define NAUTILUS_ICON_NETWORK_SERVER	"network-server-symbolic"
#define NAUTILUS_ICON_SEARCH		"system-search"
#define NAUTILUS_ICON_TRASH		"user-trash-symbolic"
#define NAUTILUS_ICON_TRASH_FULL	"user-trash-full-symbolic"
#define NAUTILUS_ICON_DELETE		"edit-delete-symbolic"

#define NAUTILUS_ICON_FOLDER_DOCUMENTS  "folder-documents-symbolic"
#define NAUTILUS_ICON_FOLDER_DOWNLOAD   "folder-download-symbolic"
#define NAUTILUS_ICON_FOLDER_MUSIC      "folder-music-symbolic"
#define NAUTILUS_ICON_FOLDER_PICTURES   "folder-pictures-symbolic"
#define NAUTILUS_ICON_FOLDER_PUBLIC_SHARE "folder-publicshare-symbolic"
#define NAUTILUS_ICON_FOLDER_TEMPLATES  "folder-templates-symbolic"
#define NAUTILUS_ICON_FOLDER_VIDEOS     "folder-videos-symbolic"
#define NAUTILUS_ICON_FOLDER_SAVED_SEARCH "folder-saved-search-symbolic"

/* Icons for desktop */
#define NAUTILUS_DESKTOP_ICON_DESKTOP    "user-desktop"
#define NAUTILUS_DESKTOP_ICON_TRASH      "user-trash"
#define NAUTILUS_DESKTOP_ICON_TRASH_FULL "user-trash-full"
#define NAUTILUS_DESKTOP_ICON_HOME       "user-home"
#define NAUTILUS_DESKTOP_ICON_NETWORK    "network-workgroup"

/* Other icons */
#define NAUTILUS_ICON_TEMPLATE		"text-x-generic-template"

/* Icons not provided by fd.o naming spec or nautilus itself */
#define NAUTILUS_ICON_BURN		"nautilus-cd-burner"

#endif /* NAUTILUS_ICON_NAMES_H */

==> nautilus-3.6.0.tar.xz: nautilus-3.6.0/libnautilus-private/nautilus-icon-names.h <==
#ifndef NAUTILUS_ICON_NAMES_H
#define NAUTILUS_ICON_NAMES_H

/* Icons for places */
#define NAUTILUS_ICON_FILESYSTEM	"drive-harddisk-symbolic"
#define NAUTILUS_ICON_FOLDER		"folder-symbolic"
#define NAUTILUS_ICON_FOLDER_REMOTE	"folder-remote-symbolic"
#define NAUTILUS_ICON_HOME		"user-home-symbolic"
#define NAUTILUS_ICON_NETWORK		"network-workgroup-symbolic"
#define NAUTILUS_ICON_NETWORK_SERVER	"network-server-symbolic"
#define NAUTILUS_ICON_SEARCH		"system-search"
#define NAUTILUS_ICON_TRASH		"user-trash-symbolic"
#define NAUTILUS_ICON_TRASH_FULL	"user-trash-full-symbolic"
#define NAUTILUS_ICON_DELETE		"edit-delete-symbolic"

#define NAUTILUS_ICON_FOLDER_DOCUMENTS  "folder-documents-symbolic"
#define NAUTILUS_ICON_FOLDER_DOWNLOAD   "folder-download-symbolic"
#define NAUTILUS_ICON_FOLDER_MUSIC      "folder-music-symbolic"
#define NAUTILUS_ICON_FOLDER_PICTURES   "folder-pictures-symbolic"
#define NAUTILUS_ICON_FOLDER_PUBLIC_SHARE "folder-publicshare-symbolic"
#define NAUTILUS_ICON_FOLDER_TEMPLATES  "folder-templates-symbolic"
#define NAUTILUS_ICON_FOLDER_VIDEOS     "folder-videos-symbolic"
#define NAUTILUS_ICON_FOLDER_SAVED_SEARCH "folder-saved-search-symbolic"

/* Icons for desktop */
#define NAUTILUS_DESKTOP_ICON_DESKTOP    "user-desktop"
#define NAUTILUS_DESKTOP_ICON_TRASH      "user-trash"
#define NAUTILUS_DESKTOP_ICON_TRASH_FULL "user-trash-full"
#define NAUTILUS_DESKTOP_ICON_HOME       "user-home"
#define NAUTILUS_DESKTOP_ICON_NETWORK    "network-workgroup"

/* Fullcolor icons */
#define NAUTILUS_ICON_FULLCOLOR_FOLDER        "folder"
#define NAUTILUS_ICON_FULLCOLOR_FOLDER_REMOTE "folder-remote"
#define NAUTILUS_ICON_FULLCOLOR_FOLDER_SAVED_SEARCH "folder-saved-search"

/* Other icons */
#define NAUTILUS_ICON_TEMPLATE		"text-x-generic-template"

/* Icons not provided by fd.o naming spec or nautilus itself */
#define NAUTILUS_ICON_BURN		"nautilus-cd-burner"

#endif /* NAUTILUS_ICON_NAMES_H */
